macro_rules! timer_queue_item_provider_impl {
($t:ty) => { ... };
}Expand description
Register a type as the global TimerQueueItemProvider implementation.
This must be done exactly once in the crate tree, by the executor.
macro_rules! timer_queue_item_provider_impl {
($t:ty) => { ... };
}Register a type as the global TimerQueueItemProvider implementation.
This must be done exactly once in the crate tree, by the executor.